import 'dart:async';

import 'package:bloc/bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/unify.dart';

import '../../services/database/database.dart';
import '../../utils/utils.dart';
import '../bloc.dart';
import 'bloc.dart';

class ContactsBloc extends Bloc<ContactsEvent, ContactsState> {
  @override
  ContactsState get initialState => InitialContactsState();

  @override
  Stream<ContactsState> mapEventToState(
    ContactsEvent event,
  ) async* {
    if (event is ContactsCheck) {
      yield ContactsLoadingState();
      const _rows = kDefaultRows;
      final _item = await GetIt.instance<DatabaseService>()
          .contactsDao
          .getLastContact(event.user.id);
      if (_item == null) {
        yield* _updateContacts(_rows, event.user);
      }
      yield ContactsReadyState();
    }
    if (event is RefreshContacts) {
      yield ContactsLoadingState();
      const _rows = kDefaultRows;
      yield* _updateContacts(_rows, event.user);
      event.scaffold.dispatch(ShowSnakBar('refreshed contacts', event.context));
      yield ContactsReadyState();
    }
  }
}

Stream<ContactsState> _updateContacts(int _rows, AccountInfo user) async* {
  var _empty = false;
  var _page = 1;
  while (!_empty) {
    final _contacts = await user.client.listContacts(
      page: _page,
      rows: _rows,
    );
    if (_contacts != null && _contacts.isNotEmpty) {
      await GetIt.instance<DatabaseService>()
          .contactsDao
          .batchUpdate(user.id, _contacts);
    } else {
      _empty = true;
    }
    _page++;
  }
  yield ContactsReadyState();
}
