import 'package:bloc/bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/unify.dart';

import '../../services/database/database.dart';
import '../../utils/utils.dart';
import '../bloc.dart';
import 'bloc.dart';

class LeadsBloc extends Bloc<LeadsEvent, LeadsState> {
  @override
  LeadsState get initialState => InitialLeadsState();

  @override
  Stream<LeadsState> mapEventToState(
    LeadsEvent event,
  ) async* {
    if (event is LeadsCheck) {
      yield LeadsLoadingState();
      const _rows = kDefaultRows;
      final _item = await GetIt.instance<DatabaseService>()
          .leadsDao
          .getLastLead(event.user.id);
      if (_item == null) {
        yield* _updateLeads(_rows, event.user);
      }
      yield LeadsReadyState();
    }
    if (event is RefreshLeads) {
      const _row = kDefaultRows;
      yield* _updateLeads(_row, event.user);
      event.scaffold.dispatch(ShowSnakBar('refreshed leads', event.context));
      yield LeadsReadyState();
    }
  }
}

Stream<LeadsState> _updateLeads(int _rows, AccountInfo user) async* {
  var _empty = false;
  var _page = 1;
  while (!_empty) {
    final _leads = await user.client.listLeads(
      page: _page,
      rows: _rows,
    );
    if (_leads != null && _leads.isNotEmpty) {
      await GetIt.instance<DatabaseService>()
          .leadsDao
          .batchUpdate(user.id, _leads);
    } else {
      _empty = true;
    }
    _page++;
  }
  yield LeadsReadyState();
}
