import 'dart:async';

import 'package:bloc/bloc.dart';
import 'package:flutter/foundation.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/unify.dart';

import '../../services/database/database.dart';
import '../../utils/utils.dart';
import '../bloc.dart';
import 'bloc.dart';

class LoansBloc extends Bloc<LoansEvent, LoansState> {
  @override
  LoansState get initialState => InitialLoansState();

  @override
  Stream<LoansState> mapEventToState(
    LoansEvent event,
  ) async* {
    if (event is LoansCheck) {
      for (var folder in LoansFolder.values) {
        yield LoansLoadingState(folder);
        final _folder = folder;
        yield* _refreshFolder(_folder, event.user, checkStale: true);
      }
      yield LoansReadyState();
    }
    if (event is RefreshLoans) {
      yield LoansLoadingState(event.folder);
      final _folder = event.folder;
      yield* _refreshFolder(_folder, event.info);
      final _context = event.context;
      event.scaffold
          .dispatch(ShowSnakBar('refreshed ${describeEnum(_folder)} loans', _context));
      yield LoansReadyState();
    }
  }

  Stream<LoansState> _refreshFolder(LoansFolder _folder, AccountInfo user,
      {bool checkStale = false}) async* {
    yield* _checkStale(checkStale, user, _folder);
  }

  Stream<LoansState> _checkStale(
      bool checkStale, AccountInfo user, LoansFolder _folder) async* {
    if (checkStale) {
      final _item = await GetIt.instance<DatabaseService>()
          .loansDao
          .getLastLoan(user.id, _folder);
      if (_item == null) {
        yield* _updateLoans(kDefaultRows, user, _folder);
      }
    } else {
      yield* _updateLoans(kDefaultRows, user, _folder);
    }
  }

  Stream<LoansState> _updateLoans(
      int _rows, AccountInfo user, LoansFolder folder) async* {
    var _empty = false;
    var _page = 1;
    while (!_empty) {
      final _loans = await user.client.listLoans(
        page: _page,
        rows: _rows,
      );
      if (_loans != null && _loans.isNotEmpty) {
        await GetIt.instance<DatabaseService>()
            .loansDao
            .batchUpdate(user.id, _loans, folder: folder);
      } else {
        _empty = true;
      }
      _page++;
    }
    yield LoansReadyState();
  }
}
