import 'package:flutter/foundation.dart';
import 'package:moor/moor.dart';

import '../database.dart';
import '../tables/settings.dart';

part 'setting.g.dart';

@UseDao(
  tables: [SettingRecords],
  queries: {
    'userById': 'SELECT * FROM users WHERE user_i_d = :id LIMIT 1',
    'settingsById':
        'SELECT * FROM settings WHERE user_id = :id AND type = :type LIMIT 1',
  },
)
class SettingDao extends DatabaseAccessor<DatabaseService>
    with _$SettingDaoMixin {
  SettingDao(DatabaseService db) : super(db);

  Future updateSetting(SettingTypes type, bool value, String color,
      {@required String userID}) async {
    final now = DateTime.now();
    final _settings = await settingsById(userID, describeEnum(type));
    if (_settings != null && _settings.isNotEmpty) {
      return await (update(settingRecords)
            ..where((t) => t.userId.equals(userID))
            ..where((t) => t.type.equals(describeEnum(type))))
          .write(
        _settings.first
            .copyWith(value: value, colorValue: color, lastUpdated: now),
      );
    }
    return await transaction((_) async {
      await into(settingRecords).insert(
        SettingRecordsCompanion(
            userId: addField<String>(userID),
            value: addField<bool>(value),
            type: addField<String>(describeEnum(type)),
            lastUpdated: addField<DateTime>(now),
            colorValue: addField<String>(color)),
        orReplace: true,
      );
    });
  }
}
