import 'package:flutter/material.dart';
import 'package:table_calendar/table_calendar.dart';

import '../../../plugins/calendar/calendar.dart';
import '../../../plugins/calendar/classes/calender.dart';

class UnifyCalendar extends StatefulWidget {
  const UnifyCalendar({
    @required this.calendarController,
    @required this.start,
    @required this.end,
    @required this.calendars,
    this.onDaySelected,
    this.onVisibleDaysChanged,
    Key key,
  }) : super(key: key);

  final CalendarController calendarController;
  // final Map<DateTime, List<dynamic>> events;
  final DateTime start, end;
  final List<DeviceCal> calendars;
  final Function(DateTime, List<dynamic>) onDaySelected;

  final Function(DateTime, DateTime, CalendarFormat) onVisibleDaysChanged;

  @override
  _UnifyCalendarState createState() => _UnifyCalendarState();

  static final Map<DateTime, List> holidays = {
    DateTime(2019, 1, 1): ['New Year\'s Day'],
    DateTime(2019, 1, 6): ['Epiphany'],
    DateTime(2019, 2, 14): ['Valentine\'s Day'],
    DateTime(2019, 4, 21): ['Easter Sunday'],
    DateTime(2019, 4, 22): ['Easter Monday'],
  };
}

class _UnifyCalendarState extends State<UnifyCalendar> {
  Map<DateTime, List<dynamic>> events = <DateTime, List<dynamic>>{};

  @override
  void initState() {
    _loadEventsFromCal();
    super.initState();
  }

  void _loadEventsFromCal() {
    if (widget?.calendars != null)
      for (var cal in widget.calendars) {
        _loadEventsForCal(
          cal.id,
          widget?.calendarController?.selectedDay ?? DateTime.now(),
        );
      }
  }

  @override
  void didUpdateWidget(UnifyCalendar oldWidget) {
    if (oldWidget.calendars != widget.calendars) {
      _loadEventsFromCal();
    }
    if (oldWidget.calendarController.selectedDay !=
        widget.calendarController.selectedDay) {
      _loadEventsFromCal();
    }
    super.didUpdateWidget(oldWidget);
  }

  void _loadEventsForCal(String id, DateTime selected) async {
    final _events = await CalendarUtils.getEventsForCalendar(
      id,
      startDate: selected.subtract(Duration(days: 30)),
      endDate: selected.add(Duration(days: 30)),
    );
    for (var event in _events) {
      if (events[event.start] == null) {
        events[event.start] = [];
      }
      events[event.start].add(event.title);
    }
  }

  @override
  Widget build(BuildContext context) {
    return TableCalendar(
      calendarController: widget.calendarController,
      events: events,
      holidays: UnifyCalendar.holidays,
      startingDayOfWeek: StartingDayOfWeek.monday,
      calendarStyle: CalendarStyle(
        selectedColor: Colors.deepOrange[400],
        todayColor: Colors.deepOrange[200],
        markersColor: Colors.brown[700],
        outsideDaysVisible: false,
      ),
      headerStyle: HeaderStyle(
        formatButtonTextStyle:
            TextStyle().copyWith(color: Colors.white, fontSize: 15.0),
        formatButtonDecoration: BoxDecoration(
          color: Colors.deepOrange[400],
          borderRadius: BorderRadius.circular(16.0),
        ),
      ),
      onDaySelected: widget.onDaySelected,
      onVisibleDaysChanged: widget.onVisibleDaysChanged,
    );
  }
}
