import 'package:example_db/data/utils/size.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:unicorndial/unicorndial.dart';

import '../../../data/blocs/bloc.dart';
import '../../../data/classes/enum_list.dart';
import '../../../data/services/database/database.dart';
import '../../search/screen.dart';
import 'data_table.dart';
import 'tile.dart';

class ContactsListScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final contacts = BlocProvider.of<ContactsBloc>(context);
    final _user = AuthBloc.currentUser(context);
    var floatButtons = List<UnicornButton>();

    return LayoutBuilder(
      builder: (context, dimens) {
        if (dimens.maxWidth > kBreakpoint) {
          return ContactsDataTable();
        }
        return Scaffold(
          floatingActionButton: FloatingActionButton(
            heroTag: 'add_search_contacts',
            child: Icon(Icons.search),
            onPressed: () {
              Navigator.of(context).pushNamed(SearchScreen.routeName,
                arguments: <String, dynamic>{
                  'type': SearchResultType.contacts
                });
            },
          ),
          body: StreamBuilder<ContactsState>(
            stream: contacts.state,
            builder: (context, snapshot) {
              final _state = snapshot.data;
              return Column(
                children: <Widget>[
                  if (_state is ContactsLoadingState) LinearProgressIndicator(),
                  Expanded(
                    child: Container(
                      child: StreamBuilder<List<Contact>>(
                          stream: GetIt.instance<DatabaseService>()
                              .contactsDao
                              .watchContactsByUser(_user.userID),
                          builder: (context, snapshot) {
                            if (snapshot.hasData) {
                              final _contacts = snapshot.data;
                              if (_contacts.isEmpty) {
                                if (_state is LoansLoadingState) {
                                  return Column(
                                    mainAxisAlignment: MainAxisAlignment.center,
                                    crossAxisAlignment:
                                        CrossAxisAlignment.center,
                                    children: [
                                      Text('No Contacts Found'),
                                      SizedBox(height: 20.0),
                                      CircularProgressIndicator(),
                                    ],
                                  );
                                }
                                return Center(child: Text('No Contacts Found'));
                              }
                              return Scrollbar(
                                child: RefreshIndicator(
                                  child: ListView.separated(
                                    separatorBuilder: (context, index) =>
                                        Divider(height: 1),
                                    itemCount: _contacts.length,
                                    itemBuilder: (context, index) {
                                      final _contact = _contacts[index];
                                      return Padding(
                                        padding: const EdgeInsets.all(7.0),
                                        child: ContactRowTile(
                                          contact: _contact,
                                          type: ViewType.detailed,
                                        ),
                                      );
                                    },
                                  ),
                                  onRefresh: () async {
                                    refresh(context);
                                    await Future.delayed(Duration(seconds: 3));
                                  },
                                ),
                              );
                            }
                            return Center(child: CircularProgressIndicator());
                          }),
                    ),
                  ),
                ],
              );
            },
          ),
        );
      },
    );
  }

  static refresh(BuildContext context) {
    final contacts = BlocProvider.of<ContactsBloc>(context);
    final _user = AuthBloc.currentInfo(context);
    final scaffold = BlocProvider.of<ScaffoldBloc>(context);
    return contacts.dispatch(RefreshContacts(
      user: _user,
      scaffold: scaffold,
      context: context
    ));
  }
}
