import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_slidable/flutter_slidable.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/tool.dart' as api;

import '../../../data/blocs/auth/bloc.dart';
import '../../../data/blocs/search/bloc.dart';
import '../../../data/classes/enum_list.dart';
import '../../../data/services/database/database.dart';
import '../../../plugins/local_storage/local_storage.dart';
import 'detailed_screen.dart';
import 'detailed_tile.dart';
import 'more_button.dart';

class ContactRowTile extends StatefulWidget {
  const ContactRowTile({
    Key key,
    @required Contact contact,
    @required ViewType type,
    this.border,
    this.iconColor,
    this.onTap,
    this.onLongPress,
  })  : _contact = contact,
        _type = type,
        super(key: key);

  final Contact _contact;
  final ViewType _type;
  final BoxDecoration border;
  final Color iconColor;
  final VoidCallback onTap, onLongPress;

  @override
  _ContactRowTileState createState() => _ContactRowTileState();
}

class _ContactRowTileState extends State<ContactRowTile> {
  LocalStor storage;
  @override
  void initState() {
    storage = LocalStor('search')..init();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final user = AuthBloc.currentUser(context);
    final info = AuthBloc.currentInfo(context);
    final _client =
        api.UnifyClient(user.username, user.password, domain: user.domain);
    final searchBloc = BlocProvider.of<SearchBloc>(context);
    switch (widget._type) {
      case ViewType.detailed:
        return GestureDetector(
          onTap: () {
            Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) =>
                        ContactDetailsScreen(contact: widget._contact)));
          },
          child: Slidable(
            actionPane: SlidableDrawerActionPane(),
            actionExtentRatio: 0.25,
            child: DetailedTile(
              contact: widget._contact,
              name: '${widget._contact.firstName} ${widget._contact.lastName}',
              subtitle: widget._contact.lastActivity,
            ),
            actions: <Widget>[
              IconSlideAction(
                caption: 'Delete',
                color: Colors.red,
                icon: Icons.delete,
                onTap: () {
                  GetIt.instance<DatabaseService>()
                      .contactsDao
                      .deleteContact(user.userID, widget._contact.contactId);
                  searchBloc.dispatch(TextChanged(text: '', user: info));
                  _client.deleteContact(widget._contact.contactId);
                },
              )
            ],
            secondaryActions: <Widget>[
              IconSlideAction(
                caption: 'Favorite',
                color: Colors.green,
                icon: Icons.star,
                onTap: () {},
              )
            ],
          ),
        );
        break;
      case ViewType.dense:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: Container(
            decoration: widget.border,
            child: ListTile(
              onLongPress: () {},
              onTap: () {
                Navigator.push(
                    context,
                    MaterialPageRoute(
                        builder: (context) =>
                            ContactDetailsScreen(contact: widget._contact)));
              },
              title: Text(
                  '${widget._contact.firstName}, ${widget._contact.lastName}'),
              subtitle: Text(widget._contact.lastActivity),
              leading: Icon(
                Icons.account_circle,
                size: 34,
                color: widget.iconColor,
              ),
              trailing: MoreButton(
                email: widget._contact.email,
                cell: widget._contact.cellPhone,
                office: widget._contact.officePhone,
                home: widget._contact.homePhone,
              ),
            ),
          ),
          actions: <Widget>[
            // IconSlideAction(
            //   caption: 'Delete',
            //   color: Colors.red,
            //   icon: Icons.delete,
            //   onTap: () {
            //     GetIt.instance<DatabaseService>().contactsDao.deleteContact(user.userID, _contact.contactId);
            //     searchBloc.dispatch(TextChanged(text: storage.getItem('query').toString(), user: info));
            //     _client.deleteContact(_contact.contactId);
            //   },
            // )
          ],
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Favorite',
              color: Colors.green,
              icon: Icons.star,
              onTap: () {},
            )
          ],
        );
        break;
    }
    return Container();
  }
}
