import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:hive/hive.dart';
import 'package:reorderables/reorderables.dart';

import '../../data/blocs/auth/bloc.dart';
import '../../data/services/database/database.dart';
import '../../plugins/path_provider/path_provider.dart';
import 'cards/index.dart';
import 'common/render.dart';

class DashboardHomeScreen extends StatefulWidget {
  @override
  _DashboardHomeScreenState createState() => _DashboardHomeScreenState();
}

class _DashboardHomeScreenState extends State<DashboardHomeScreen> {
  @override
  Widget build(BuildContext context) {
    final _tags = [
      CurrentRatesCard.cardKey,
      CurrentWeatherCard.cardKey,
      ActionButtonCard.cardKey,
      DashboardAlertsCard.cardKey
    ];
    final _user = AuthBloc.currentUser(context);
    return FutureBuilder(
        future: initHive(),
        builder: (context, snapshot) {
          return Scaffold(
              floatingActionButton: FloatingActionButton(
                child: Icon(Icons.add),
                onPressed: () => _addWidget(context, _tags, _user),
              ),
              body: SafeArea(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Expanded(
                      child: StreamBuilder<List<DashboardWidget>>(
                          stream: GetIt.instance<DatabaseService>()
                              .homeDao
                              .watchItemsForUser(_user.userID),
                          builder: (context, snapshot) {
                            if (!snapshot.hasData) {
                              return Center(
                                child: CircularProgressIndicator(),
                              );
                            }
                            final _items = snapshot.data;
                            if (_items.isEmpty) {
                              return Container(
                                child: Center(
                                  child: Column(
                                    mainAxisAlignment: MainAxisAlignment.center,
                                    crossAxisAlignment:
                                        CrossAxisAlignment.center,
                                    children: <Widget>[
                                      Text('No Items Found'),
                                      SizedBox(height: 10.0),
                                      RaisedButton.icon(
                                        icon: Icon(Icons.add),
                                        label: Text('Add Item'),
                                        onPressed: () =>
                                            _addWidget(context, _tags, _user),
                                      ),
                                    ],
                                  ),
                                ),
                              );
                            }
                            return Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: <Widget>[
                                Expanded(
                                  child: Container(
                                    // color: Colors.green,
                                    child: ReorderableWrap(
                                      buildDraggableFeedback:
                                          (context, dimens, child) =>
                                              SizedBox.fromSize(
                                        size: Size(
                                            dimens.maxWidth, dimens.maxHeight),
                                        child: child,
                                      ),
                                      onReorder: (oldIndex, newIndex) {
                                        if (newIndex > oldIndex) {
                                          newIndex -= 1;
                                        }
                                        final item = _items.removeAt(oldIndex);
                                        _items.insert(newIndex, item);
                                      },
                                      spacing: 20.0,
                                      runSpacing: 20.0,
                                      padding: EdgeInsets.all(22.0),
                                      children: <Widget>[
                                        for (var item in _items) ...[
                                          Container(
                                            key: ValueKey(
                                                '${item.tag}_${item.itemId}'),
                                            child: CardRender(item: item),
                                          ),
                                        ],
                                      ],
                                    ),
                                  ),
                                ),
                              ],
                            );
                          }),
                    ),
                  ],
                ),
              ));
        });
  }

  Future initHive() async {
    if (!kIsWeb) {
      final dir = await DirUtils.getLocalPath();
      return Hive.init(dir);
    }
    return;
  }

  Future _addWidget(
      BuildContext context, List<String> _tags, User _user) async {
    final tag = await showDialog<String>(
      context: context,
      builder: (_) => AlertDialog(
        title: Text('Tags'),
        content: Container(
            child: Column(
          children: <Widget>[
            for (var tag in _tags) ...[
              RaisedButton(
                child: Text(tag),
                onPressed: () => Navigator.pop(context, tag),
              ),
            ],
          ],
        )),
      ),
    );
    if (tag != null) {
      await GetIt.instance<DatabaseService>()
          .homeDao
          .addItem(tag, _user.userID);
    }
  }
}
