import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_slidable/flutter_slidable.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/unify.dart' as api;

import '../../../data/blocs/auth/bloc.dart';
import '../../../data/blocs/bloc.dart';
import '../../../data/classes/enum_list.dart';
import '../../../data/services/database/database.dart';
import '../../../plugins/local_storage/local_storage.dart';
import '../../contacts/common/more_button.dart';
import 'detailed_lead_tile.dart';

class LeadRowTile extends StatelessWidget {
  const LeadRowTile(
      {Key key,
      @required Lead lead,
      @required ViewType type,
      this.border,
      this.iconColor,
      this.onTap,
      this.onLongPress})
      : _lead = lead,
        _type = type,
        super(key: key);

  final Lead _lead;
  final ViewType _type;
  final BoxDecoration border;
  final Color iconColor;
  final VoidCallback onTap, onLongPress;

  @override
  Widget build(BuildContext context) {
    final storage = LocalStor('search');
    final user = AuthBloc.currentUser(context);
    final info = AuthBloc.currentInfo(context);
    final _client =
        api.UnifyClient(user.username, user.password, domain: user.domain);
    final searchBloc = BlocProvider.of<SearchBloc>(context);
    switch (_type) {
      case ViewType.detailed:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: DetailedLeadTile(
            lead: _lead,
            name: '${_lead.firstName} ${_lead.lastName}',
            subtitle: _lead.lastActivity,
          ),
          actions: <Widget>[
            IconSlideAction(
              caption: 'Delete',
              color: Colors.red,
              icon: Icons.delete,
              onTap: () {
                GetIt.instance<DatabaseService>()
                    .leadsDao
                    .deleteLead(user.userID, _lead.leadId);
                searchBloc.dispatch(TextChanged(text: '', user: info));
                _client.deleteLead(_lead.leadId);
              },
            )
          ],
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Favorite',
              color: Colors.green,
              icon: Icons.star,
              onTap: () {},
            )
          ],
        );
        break;
      case ViewType.dense:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: Container(
            decoration: border,
            child: ListTile(
              onLongPress: () {},
              onTap: () {},
              title: Text('${_lead.firstName}, ${_lead.lastName}'),
              subtitle: Text(_lead.lastActivity),
              leading: Icon(
                Icons.people,
                size: 34,
                color: iconColor,
              ),
              trailing: MoreButton(
                email: _lead.email,
                cell: _lead.cellPhone,
                office: _lead.officePhone,
                home: _lead.homePhone,
              ),
            ),
          ),
          // actions: <Widget>[
          //   IconSlideAction(
          //     caption: 'Delete',
          //     color: Colors.red,
          //     icon: Icons.delete,
          //     onTap: () {},
          //   )
          // ],
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Favorite',
              color: Colors.green,
              icon: Icons.star,
              onTap: () {},
            )
          ],
        );
        break;
    }
    return Container();
  }
}
