import 'package:example_db/data/classes/enum_list.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/unify.dart' as api;

import '../../../data/blocs/bloc.dart';
import '../../../data/services/database/database.dart';
import 'tile.dart';

class LoanFolderScreen extends StatelessWidget {
  const LoanFolderScreen({
    Key key,
    @required this.folder,
  }) : super(key: key);

  final api.LoansFolder folder;

  @override
  Widget build(BuildContext context) {
    final loans = BlocProvider.of<LoansBloc>(context);
    final _user = AuthBloc.currentUser(context);
    return StreamBuilder<LoansState>(
        stream: loans.state,
        builder: (context, snapshot) {
          final _state = snapshot.data;
          return Column(
            children: <Widget>[
              if (_state is LoansLoadingState && _state.folder == folder)
                LinearProgressIndicator(),
              Expanded(
                child: Container(
                  child: StreamBuilder<List<Loan>>(
                      stream: GetIt.instance<DatabaseService>()
                          .loansDao
                          .watchLoansByFolder(
                              _user.userID, describeEnum(folder)),
                      builder: (context, snapshot) {
                        if (snapshot.hasData) {
                          final _loans = snapshot.data;
                          if (_loans.isEmpty) {
                            if (_state is LoansLoadingState) {
                              return Column(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                children: [
                                  Text('No Loans Found'),
                                  SizedBox(height: 20.0),
                                  CircularProgressIndicator(),
                                ],
                              );
                            }
                            return Center(child: Text('No Loans Found'));
                          }
                          return Scrollbar(
                            child: RefreshIndicator(
                              child: ListView.separated(
                                separatorBuilder: (context, index) =>
                                    Divider(height: 1),
                                itemCount: _loans.length,
                                itemBuilder: (context, index) {
                                  final _loan = _loans[index];
                                  return LoanRowTile(
                                    loan: _loan,
                                    type: ViewType.detailed,
                                  );
                                },
                              ),
                              onRefresh: () async {
                                refresh(context, folder);
                                await Future.delayed(Duration(seconds: 3));
                              },
                            ),
                          );
                        }
                        return Center(child: CircularProgressIndicator());
                      }),
                ),
              ),
            ],
          );
        });
  }

  static refresh(BuildContext context, api.LoansFolder folder) {
    final loans = BlocProvider.of<LoansBloc>(context);
    final _user = AuthBloc.currentInfo(context);
    final scaffold = BlocProvider.of<ScaffoldBloc>(context);
    return loans.dispatch(RefreshLoans(
      info: _user,
      folder: folder,
      scaffold: scaffold,
      context: context
    ));
  }
}
