import 'package:example_db/data/blocs/bloc.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:recase/recase.dart';
import 'package:unify_api/unify.dart' as api;

import '../../../data/services/database/database.dart';
import '../../search/screen.dart';
import 'folder.dart';
import 'search.dart';

class LoanListScreen extends StatefulWidget {
  @override
  _LoanListScreenState createState() => _LoanListScreenState();
}

class _LoanListScreenState extends State<LoanListScreen> {
  int _currenIndex = 0;
  @override
  Widget build(BuildContext context) {
    final _folders = [
      api.LoansFolder.all,
      api.LoansFolder.mypipeline,
      api.LoansFolder.activeloans,
      api.LoansFolder.prospects,
      api.LoansFolder.closed,
      api.LoansFolder.other,
    ];
    return DefaultTabController(
      initialIndex: _currenIndex,
      length: _folders.length,
      child: Scaffold(
        // appBar: AppBar(
        //   title: Text('Loans'),
        //   actions: <Widget>[
        //     IconButton(
        //       icon: Icon(Icons.refresh),
        //       onPressed: () {
        //         LoanFolderScreen.refresh(
        //             context, api.LoansFolder.values[_currenIndex]);
        //       },
        //     ),
        //   ],
        //   bottom: TabBar(
        //     onTap: (val) => _currenIndex = val,
        //     isScrollable: true,
        //     tabs: <Widget>[
        //       for (var folder in _folders) ...[
        //         Tab(
        //           text: _getTitle(folder),
        //         )
        //       ],
        //     ],
        //   ),
        // ),
        appBar: PreferredSize(
          preferredSize: Size.fromHeight(60),
          child: Center(
            child: TabBar(
              onTap: (val) => _currenIndex = val,
              isScrollable: true,
              tabs: <Widget>[
                for (var folder in _folders) ...[
                  Tab(
                    text: _getTitle(folder),
                  )
                ],
              ],
            ),
          ),
        ),
        body: TabBarView(
          children: <Widget>[
            for (var folder in _folders) ...[LoanFolderScreen(folder: folder)]
          ],
        ),
        floatingActionButton: FloatingActionButton(
          heroTag: 'search_loans',
          child: Icon(Icons.search),
          onPressed: () {
            Navigator.of(context).pushNamed(SearchScreen.routeName,
                arguments: <String, dynamic>{
                  'type': SearchResultType.loans.index
                });
          },
        ),
      ),
    );
  }

  String _getTitle(api.LoansFolder folder) {
    switch (folder) {
      case api.LoansFolder.all:
      case api.LoansFolder.other:
      case api.LoansFolder.closed:
      case api.LoansFolder.prospects:
        return ReCase(describeEnum(folder)).titleCase;
      case api.LoansFolder.activeloans:
        return 'Active Loans';
      case api.LoansFolder.mypipeline:
        return 'My Pipeline';
      default:
    }
    return describeEnum(folder);
  }

  static Future<Loan> searchLoan(BuildContext context,
      {api.LoansFolder folder = api.LoansFolder.all}) async {
    final _loan = await showSearch<Loan>(
      context: context,
      delegate: LoansSearchDelegate(folder),
    );
    return _loan;
  }
}
