import 'package:flutter/material.dart';
import 'package:flutter_slidable/flutter_slidable.dart';

import '../../../data/classes/enum_list.dart';
import '../../../data/services/database/database.dart';
import '../../contacts/common/more_button.dart';
import 'detailed_loan_tile.dart';

class LoanRowTile extends StatelessWidget {
  const LoanRowTile({
    Key key,
    @required Loan loan,
    @required ViewType type,
    this.border,
    this.iconColor,
    this.onTap,
    this.onLongPress,
  })  : _loan = loan,
        _type = type,
        super(key: key);

  final Loan _loan;
  final ViewType _type;
  final BoxDecoration border;
  final Color iconColor;
  final VoidCallback onTap, onLongPress;

  @override
  Widget build(BuildContext context) {
    switch (_type) {
      case ViewType.detailed:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: DetailedLoanTile(
            loan: _loan,
            name: '${_loan.firstName} ${_loan.lastName}',
            subtitle: _loan.loanMilestone,
          ),
          actions: <Widget>[
            IconSlideAction(
              caption: 'Delete',
              color: Colors.red,
              icon: Icons.delete,
              onTap: () {},
            )
          ],
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Favorite',
              color: Colors.green,
              icon: Icons.star,
              onTap: () {},
            )
          ],
        );
        break;
      case ViewType.dense:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: Container(
            decoration: border,
            child: ListTile(
              onLongPress: () {},
              onTap: () {},
              title: Text('${_loan.firstName}, ${_loan.lastName}'),
              subtitle: Text(_loan.loanMilestone),
              leading: Icon(
                Icons.folder,
                size: 34,
                color: iconColor,
              ),
              trailing: MoreButton(
                email: _loan.email,
                cell: _loan.cellPhone,
                office: _loan.officePhone,
                home: _loan.homePhone,
              ),
            ),
          ),
          actions: <Widget>[
            IconSlideAction(
              caption: 'Delete',
              color: Colors.red,
              icon: Icons.delete,
              onTap: () {},
            )
          ],
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Favorite',
              color: Colors.green,
              icon: Icons.star,
              onTap: () {},
            )
          ],
        );
        break;
    }
  }
}
