import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';

import '../../data/blocs/bloc.dart';
import '../../data/services/database/database.dart';
import '../../data/services/database/tables/settings.dart';

class SettingBuilder extends StatelessWidget {
  const SettingBuilder({
    @required this.type,
    Key key,
    this.builder,
    this.fallback = false,
    this.sFallback = 0xffffffff,
  }) : super(key: key);
  final SettingTypes type;
  final bool fallback;
  final int sFallback;
  final Widget Function(BuildContext, Setting, bool, int) builder;

  @override
  Widget build(BuildContext context) {
    final db = GetIt.instance<DatabaseService>().settingDao;
    return StreamBuilder<AuthState>(
      stream: BlocProvider.of<AuthBloc>(context).state,
      builder: (context, auth) {
        if (auth.hasData) {
          final _auth = auth.data;
          if (_auth is LoggedInState) {
            return StreamBuilder<List<Setting>>(
                stream: db.watchSettingsById(
                  _auth.user.userID,
                  describeEnum(type),
                ),
                builder: (context, snapshot) {
                  if (snapshot.hasData) {
                    final _data = snapshot?.data;
                    if (_data != null && _data.isNotEmpty) {
                      if (type == SettingTypes.contactColor ||
                          type == SettingTypes.leadColor ||
                          type == SettingTypes.loanColor ||
                          type == SettingTypes.alertColor ||
                          type == SettingTypes.videoColor) {
                        final _color = _data.first.colorValue ?? sFallback;
                        final _colorVal = int.parse(_color);
                        return builder(
                            context, _data?.first, fallback, _colorVal);
                      }
                      final _value = _data.first.value ?? fallback;
                      return builder(context, _data?.first, _value, sFallback);
                    }
                  }
                  return builder(context, null, fallback, sFallback);
                });
          }
        }
        return builder(context, null, fallback, sFallback);
      },
    );
  }
}
