import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_material_color_picker/flutter_material_color_picker.dart';
import 'package:get_it/get_it.dart';
import 'package:unify_api/tool.dart';

import '../../data/blocs/bloc.dart';
import '../../data/services/database/dao/setting.dart';
import '../../data/services/database/database.dart';
import '../../data/services/database/tables/settings.dart';
import '../auth/screen.dart';
import '../common/common.dart';
import 'builder.dart';

class SettingsScreen extends StatefulWidget {
  @override
  _SettingsScreenState createState() => _SettingsScreenState();
}

class _SettingsScreenState extends State<SettingsScreen> {
  int tempColor = 0;

  String _buildTitle(SettingTypes type) {
    switch (type) {
      case SettingTypes.darkMode:
        return 'Dark Mode';
      case SettingTypes.autoLogin:
        return 'Auto Login';
      case SettingTypes.contactColor:
        return 'Contact Indicator Color';
      case SettingTypes.loanColor:
        return 'Loan Indicator Color';
      case SettingTypes.leadColor:
        return 'Lead Indicator Color';
      case SettingTypes.alertColor:
        return 'Alert Indicator Color';
      case SettingTypes.videoColor:
        return 'Video Indicator Color';
      default:
        return describeEnum(type);
    }
  }

  @override
  Widget build(BuildContext context) {
    final _user = AuthBloc.currentInfo(context);
    final auth = BlocProvider.of<AuthBloc>(context);
    final db = GetIt.instance<DatabaseService>().settingDao;
    final nav = BlocProvider.of<NavBloc>(context);
    return Scaffold(
      // appBar: AppBar(
      //   // leading: MenuButton(),
      //   title: Text('Settings'),
      //   actions: <Widget>[
      //     IconButton(
      //       icon: Icon(Icons.account_circle),
      //       onPressed: () => nav.dispatch(NavPushEvent(LoginScreen.routeName,
      //           args: const <String, dynamic>{
      //             'add': true,
      //           })),
      //     ),
      //     IconButton(
      //       icon: Icon(Icons.exit_to_app),
      //       onPressed: () => auth.dispatch(LogoutEvent(_user)),
      //     ),
      //   ],
      // ),
      body: ListView(
        children: <Widget>[
          SettingBuilder(
            type: SettingTypes.darkMode,
            builder: (context, settings, val, string) =>
                SwitchListTile.adaptive(
              title: Text(_buildTitle(SettingTypes.darkMode)),
              value: val,
              onChanged: (val) => db.updateSetting(
                  SettingTypes.darkMode, val, null,
                  userID: _user.id),
            ),
          ),
          SettingBuilder(
            type: SettingTypes.autoLogin,
            fallback: true,
            builder: (context, settings, val, string) =>
                SwitchListTile.adaptive(
              title: Text(_buildTitle(SettingTypes.autoLogin)),
              value: val,
              onChanged: (val) => db.updateSetting(
                  SettingTypes.autoLogin, val, null,
                  userID: _user.id),
            ),
          ),
          ExpansionTile(
            title: Text('Color Options',
                style: Theme.of(context).textTheme.subhead),
            children: <Widget>[
              SettingBuilder(
                type: SettingTypes.contactColor,
                sFallback: 0xff4a62ff,
                builder: (context, settings, val, color) => Padding(
                  padding: EdgeInsets.all(17),
                  child: Row(
                    children: <Widget>[
                      Expanded(
                          child: Text(
                        _buildTitle(SettingTypes.contactColor),
                        style: Theme.of(context).textTheme.subhead,
                      )),
                      CircleAvatar(
                        backgroundColor: Color(color),
                        child: FlatButton(
                          onPressed: () {
                            _openColorPicker(
                                SettingTypes.contactColor, color, db, _user);
                          },
                        ),
                      )
                    ],
                  ),
                ),
              ),
              SettingBuilder(
                type: SettingTypes.loanColor,
                sFallback: 0xff86a6b8,
                builder: (context, settings, val, color) => Padding(
                  padding: EdgeInsets.all(17),
                  child: Row(
                    children: <Widget>[
                      Expanded(
                          child: Text(
                        _buildTitle(SettingTypes.loanColor),
                        style: Theme.of(context).textTheme.subhead,
                      )),
                      CircleAvatar(
                        backgroundColor: Color(color),
                        child: FlatButton(
                          onPressed: () {
                            _openColorPicker(
                                SettingTypes.loanColor, color, db, _user);
                          },
                        ),
                      )
                    ],
                  ),
                ),
              ),
              SettingBuilder(
                type: SettingTypes.leadColor,
                sFallback: 0xff59ba57,
                builder: (context, settings, val, color) => Padding(
                  padding: EdgeInsets.all(17),
                  child: Row(
                    children: <Widget>[
                      Expanded(
                          child: Text(
                        _buildTitle(SettingTypes.leadColor),
                        style: Theme.of(context).textTheme.subhead,
                      )),
                      CircleAvatar(
                        backgroundColor: Color(color),
                        child: FlatButton(
                          onPressed: () {
                            _openColorPicker(
                                SettingTypes.leadColor, color, db, _user);
                          },
                        ),
                      )
                    ],
                  ),
                ),
              ),
              SettingBuilder(
                type: SettingTypes.alertColor,
                sFallback: 0xffff0000,
                builder: (context, settings, val, color) => Padding(
                  padding: EdgeInsets.all(17),
                  child: Row(
                    children: <Widget>[
                      Expanded(
                          child: Text(
                        _buildTitle(SettingTypes.alertColor),
                        style: Theme.of(context).textTheme.subhead,
                      )),
                      CircleAvatar(
                        backgroundColor: Color(color),
                        child: FlatButton(
                          onPressed: () {
                            _openColorPicker(
                                SettingTypes.alertColor, color, db, _user);
                          },
                        ),
                      )
                    ],
                  ),
                ),
              ),
              SettingBuilder(
                type: SettingTypes.videoColor,
                sFallback: 0xffeba817,
                builder: (context, settings, val, color) => Padding(
                  padding: EdgeInsets.all(17),
                  child: Row(
                    children: <Widget>[
                      Expanded(
                          child: Text(
                        _buildTitle(SettingTypes.videoColor),
                        style: Theme.of(context).textTheme.subhead,
                      )),
                      CircleAvatar(
                        backgroundColor: Color(color),
                        child: FlatButton(
                          onPressed: () {
                            _openColorPicker(
                                SettingTypes.videoColor, color, db, _user);
                          },
                        ),
                      )
                    ],
                  ),
                ),
              )
            ],
          ),
          ListTile(
            title: RaisedButton.icon(
              icon: Icon(Icons.exit_to_app),
              label: Text('Logout'),
              onPressed: () => auth.dispatch(LogoutEvent(_user)),
            ),
          ),
          ListTile(
            title: FlatButton.icon(
              icon: Icon(Icons.add),
              label: Text('Add Account'),
              onPressed: () => Navigator.pushNamed(
                  context, LoginScreen.routeName,
                  arguments: {'add': true}),
            ),
          ),
        ],
      ),
    );
  }

  Future<T> _openDialog<T>(Widget content) {
    return showDialog<T>(
        context: context,
        builder: (_) {
          return AlertDialog(
            contentPadding: EdgeInsets.all(6),
            title: Text('Select a Color'),
            content: content,
          );
        });
  }

  void _openColorPicker(
      SettingTypes setting, int color, SettingDao db, AccountInfo user) async {
    await _openDialog(
      MaterialColorPicker(
          colors: fullMaterialColors,
          allowShades: false,
          selectedColor: Color(color),
          onMainColorChange: (color) {
            setState(() {
              tempColor = color.value;
              db.updateSetting(setting, false, tempColor.toString(),
                  userID: user.id);
            });
          }),
    );
  }
}
