import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:get_it/get_it.dart';

import '../../../data/blocs/auth/bloc.dart';
import '../../../data/blocs/scaffold/scaffold_bloc.dart';
import '../../../data/blocs/videos/bloc.dart';
import '../../../data/blocs/videos/videos_bloc.dart';
import '../../../data/classes/enum_list.dart';
import '../../../data/services/database/database.dart';
import 'tile.dart';

class VideoListScreen extends StatefulWidget {
  @override
  _VideoListScreenState createState() => _VideoListScreenState();

  static refresh(BuildContext context) {
    final videos = BlocProvider.of<VideosBloc>(context);
    final _user = AuthBloc.currentInfo(context);
    final scaffold = BlocProvider.of<ScaffoldBloc>(context);
    return videos.dispatch(
        RefreshVideos(user: _user, scaffold: scaffold, context: context));
  }
}

class _VideoListScreenState extends State<VideoListScreen> {
  int _currenIndex = 0;
  @override
  Widget build(BuildContext context) {
    final videos = BlocProvider.of<VideosBloc>(context);
    final _user = AuthBloc.currentUser(context);
    final _folders = [
      'My Videos',
      'Shared',
      'Archived',
    ];
    return DefaultTabController(
      initialIndex: _currenIndex,
      length: _folders.length,
      child: Scaffold(
        // appBar: AppBar(
        //   title: Text('Videos'),
        //   actions: <Widget>[
        //     IconButton(
        //       icon: Icon(Icons.refresh),
        //       onPressed: () => refresh(context),
        //     )
        //   ],
        // ),
        appBar: PreferredSize(
          preferredSize: Size.fromHeight(60),
          child: Center(
            child: TabBar(
              onTap: (val) => _currenIndex = val,
              isScrollable: true,
              tabs: <Widget>[
                for (var folder in _folders) ...[Tab(text: folder)],
              ],
            ),
          ),
        ),
        floatingActionButton: FloatingActionButton(
          heroTag: 'record_video',
          child: Icon(FontAwesomeIcons.video),
          onPressed: () {},
        ),
        body: StreamBuilder<VideosState>(
            stream: videos.state,
            builder: (context, snapshot) {
              final _state = snapshot.data;
              return Column(
                children: <Widget>[
                  if (_state is VideosLoadingState) LinearProgressIndicator(),
                  Expanded(
                    child: Container(
                        child: StreamBuilder<List<Video>>(
                            stream: GetIt.instance<DatabaseService>()
                                .videoDao
                                .watchVideosByUser(_user.userID),
                            builder: (context, snapshot) {
                              if (snapshot.hasData) {
                                final _videos = snapshot.data;
                                if (_videos.isEmpty) {
                                  if (_state is VideosLoadingState) {
                                    return Column(
                                      mainAxisAlignment:
                                          MainAxisAlignment.center,
                                      crossAxisAlignment:
                                          CrossAxisAlignment.center,
                                      children: [
                                        Text('No Videos Found'),
                                        SizedBox(height: 20.0),
                                        CircularProgressIndicator(),
                                      ],
                                    );
                                  }
                                  return Center(child: Text('No Videos Found'));
                                }
                                return Scrollbar(
                                  child: RefreshIndicator(
                                    child: ListView.separated(
                                        separatorBuilder: (context, index) =>
                                            Divider(height: 1),
                                        itemCount: _videos.length,
                                        itemBuilder: (context, index) {
                                          final _video = _videos[index];
                                          return Padding(
                                              padding: const EdgeInsets.all(7),
                                              child: VideoRowTile(
                                                video: _video,
                                                type: ViewType.detailed,
                                              ));
                                        }),
                                    onRefresh: () async {
                                      VideoListScreen.refresh(context);
                                      await Future.delayed(
                                          Duration(seconds: 3));
                                    },
                                  ),
                                );
                              }
                              return Center(child: CircularProgressIndicator());
                            })),
                  )
                ],
              );
            }),
      ),
    );
  }
}
