import 'package:flutter/material.dart';
import 'package:flutter_slidable/flutter_slidable.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import '../../../data/classes/enum_list.dart';
import '../../../data/services/database/database.dart';
import '../../../plugins/video_player/video_player.dart';


class VideoRowTile extends StatelessWidget {
  const VideoRowTile(
      {Key key,
      @required Video video,
      @required ViewType type,
      this.border,
      this.iconColor,
      this.onTap,
      this.onLongPress})
      : _video = video,
        _type = type,
        super(key: key);

  final BoxDecoration border;
  final Color iconColor;
  final VoidCallback onTap, onLongPress;

  final ViewType _type;
  final Video _video;

  @override
  Widget build(BuildContext context) {
    switch (_type) {
      case ViewType.detailed:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: InkWell(
            onTap: () {
              print('TEST');
            },
            child: ExpansionTile(
              title: ListTile(
                leading: Icon(FontAwesomeIcons.video),
                title: Text('${_video.name}'),
                subtitle: Text('${_video.description}'),
              ),
              children: <Widget>[
                Container(
                  child: VideoPlayerView(
                    src: _video.download,
                    width: _video.width,
                    height: _video.height,
                  ),
                )
              ],
            ),
          ),
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Archive',
              color: Colors.green,
              icon: Icons.archive,
              onTap: () {},
            )
          ],
        );
        break;
      case ViewType.dense:
        return Slidable(
          actionPane: SlidableDrawerActionPane(),
          actionExtentRatio: 0.25,
          child: InkWell(
            child: Container(
              decoration: border,
              child: ExpansionTile(
                title: ListTile(
                  title: Text('${_video.name}'),
                  subtitle: Text('${_video.description}',
                      style: Theme.of(context)
                          .textTheme
                          .caption
                          .copyWith(fontSize: 14)),
                  leading: Icon(
                    FontAwesomeIcons.video,
                    color: iconColor,
                  ),
                ),
                children: <Widget>[
                  Container(
                    child: VideoPlayerView(
                      src: _video.download,
                      width: _video.width,
                      height: _video.height,
                    ),
                  )
                ],
              ),
            ),
          ),
          secondaryActions: <Widget>[
            IconSlideAction(
              caption: 'Archive',
              color: Colors.green,
              icon: Icons.archive,
            )
          ],
        );
        break;
    }
  }
}
